@@ -13,6 +13,8 @@ def remove_annotations(xsd_tree):
 
     """
     # find all annotations
-    annotations = xsd_tree.findall(".//{}annotation".format(xml_utils_constants.LXML_SCHEMA_NAMESPACE))
+    annotations = xsd_tree.findall(
+        ".//{}annotation".format(xml_utils_constants.LXML_SCHEMA_NAMESPACE)
+    )
     for annotation in annotations:
         annotation.getparent().remove(annotation)
